@@ -35,7 +35,7 @@ interface AuthLoginArgs {
     workstation?: string;
 }
 
-// eslint-disable-next-line no-shadow
+
 export enum AuthWsState {
     PENDING,
     NOT_USED,
@@ -52,6 +52,9 @@ export class AuthService {
 
     private authChannel: any;
 
+    SSOEnabled = false;
+    allowNativeLogin = true;
+
     private activeUser: AuthUser = null;
 
     workstationState: AuthWsState = AuthWsState.PENDING;
@@ -157,6 +160,26 @@ export class AuthService {
         });
     }
 
+    SSOSettings(ws_name: string): Promise<any> {
+        return this.net.request(
+            'open-ils.actor',
+            'open-ils.actor.org_unit_settings.by_workstation.retrieve',
+            ['staff.login.shib_sso.enable','staff.login.shib_sso.allow_native'],
+            ws_name
+        ).toPromise().then(settings => {
+            settings.forEach(s => {
+                if (s.value !== null) {
+                    if (s.name === 'staff.login.shib_sso.enable') {
+                        this.SSOEnabled = s.value;
+                    } else if (s.name === 'staff.login.shib_sso.allow_native') {
+                        this.allowNativeLogin = s.value;
+                    }
+                }
+            });
+            return this;
+        });
+    }
+
     loginApi(args: AuthLoginArgs, service: string,
         method: string, isOpChange?: boolean): Promise<void> {
 
@@ -352,8 +375,7 @@ export class AuthService {
             // NetService intercepts NO_SESSION events.
             // If the promise resolves, the session is valid.
             ).subscribe(
-                user => this.sessionPoll(),
-                (err: unknown)  => console.warn('auth poll error: ' + err)
+                { next: user => this.sessionPoll(), error: (err: unknown)  => console.warn('auth poll error: ' + err) }
             );
 
         }, pollTime);
