@@ -8,12 +8,14 @@ import { StoreService } from '@eg/core/store.service';
 import { CatalogSearchContext } from '@eg/share/catalog/search-context';
 import { StaffCatalogService } from '@eg/staff/catalog/catalog.service';
 import { SerialsService } from '@eg/staff/serials/serials.service';
-import { of } from 'rxjs';
+import { HoldsService } from '@eg/staff/share/holds/holds.service';
+import { PatronService } from '@eg/staff/share/patron/patron.service';
+import { EMPTY, from, of } from 'rxjs';
 
 // Convenience functions that generate mock data for use in automated tests
 export class MockGenerators {
-    static idlObject(keysAndValues: {[key: string]: any}) {
-        const object = jasmine.createSpyObj<IdlObject>(Object.keys(keysAndValues));
+    static idlObject(keysAndValues: {[key: string]: any}, classname?: string) {
+        const object = jasmine.createSpyObj<IdlObject>(Object.keys(keysAndValues), {classname: classname});
         Object.keys(keysAndValues).forEach((key) => {
             object[key].and.returnValue(keysAndValues[key]);
         });
@@ -28,8 +30,38 @@ export class MockGenerators {
         return auth;
     }
 
+    static holdsService() {
+        const service = jasmine.createSpyObj<HoldsService>(['getHoldTargetMeta', 'placeHold']);
+        service.placeHold.and.returnValue(of({
+            holdType: 'B',
+            holdTarget: 1,
+            recipient: 2,
+            requestor: 3,
+            pickupLib: 4,
+            result: { success: true, holdId: 303 }
+        }));
+        service.getHoldTargetMeta.and.returnValue(EMPTY);
+        return service;
+    }
+
     static idlService(classes: {}) {
-        return jasmine.createSpyObj<IdlService>(['getClassSelector'], {classes: classes});
+        const service = jasmine.createSpyObj<IdlService>(['getClassSelector', 'create'], {classes: classes});
+        service.create.and.callFake((cls: string, seed?: any) => {
+            return new Proxy({
+                a: [],
+                classname: cls,
+                _isfieldmapper: true
+            }, {
+                get(target, property, receiver) {
+                    if (['a', 'classname', '_isfieldmapper'].includes(property as string)) {
+                        return target[property];
+                    } else {
+                        return (value) => null;
+                    }
+                }
+            });
+        });
+        return service;
     }
 
     // Use the method response map to say which OpenSRF methods
@@ -47,21 +79,23 @@ export class MockGenerators {
         return net;
     }
 
+    static patronService() {
+        const patron = jasmine.createSpyObj<PatronService>(['getById']);
+        patron.getById.and.resolveTo(this.idlObject({id: 1, day_phone: '555-1234', settings: [], email: null, home_ou: 1}));
+        return patron;
+    }
+
     static permService(permissions_result: {}) {
         const perm = jasmine.createSpyObj<PermService>(['hasWorkPermHere']);
         perm.hasWorkPermHere.and.resolveTo(permissions_result);
         return perm;
     }
 
-    static pcrudService(returnValues: {[method: string]: any}) {
+    static pcrudService(returnValues: {[method: string]: any[]}) {
         const methods = ['search', 'retrieve', 'retrieveAll', 'create', 'update', 'remove'];
         const pcrud = jasmine.createSpyObj<PcrudService>(['search', 'retrieve', 'retrieveAll', 'create', 'update', 'remove']);
         methods.forEach((method) => {
-            if (returnValues[method]) {
-                pcrud[method].and.returnValue(of(returnValues[method]));
-            } else {
-                pcrud[method].and.returnValue(of());
-            }
+            pcrud[method].and.returnValue(from(returnValues[method] || []));
         });
         return pcrud;
     }
@@ -101,6 +135,17 @@ export class MockGenerators {
     }
 
     static orgService() {
-        return {ancestors: () => []};
+        return {
+            ancestors: () => [],
+            list: () => of([]),
+            settings: () => Promise.resolve(null),
+        };
     }
 }
+
+interface BasicGlobalFlag {
+    name: string;
+    enabled: boolean;
+    label?: string;
+    value?: string;
+}
