@@ -1179,8 +1179,18 @@ CREATE OR REPLACE FUNCTION vandelay.add_field ( target_xml TEXT, source_xml TEXT
                 } else {
                     for my $to_field (@tos) {
                         if (exists($fields{$f}{match})) {
-                            my @match_list = grep { $to_field->subfield($_) =~ $fields{$f}{match}{$_} } keys %{$fields{$f}{match}};
-                            next unless (scalar(@match_list) == scalar(keys %{$fields{$f}{match}}));
+                            my @match_list;
+                            for my $match_key_sf_code ( keys %{$fields{$f}{match}} ) {
+                                # We loop here because there might be multiple SFs, such as multiple
+                                # $0s in an authority controlled datafield, where one has the EG-special
+                                # format, and others are links to external heading data.
+                                for my $sf_content ($to_field->subfield($match_key_sf_code)) {
+                                    if ($sf_content =~ $fields{$f}{match}{$match_key_sf_code}) {
+                                        push @match_list, $sf_content;
+                                    }
+                                }
+                            }
+                            next unless (scalar(@match_list) >= scalar(keys %{$fields{$f}{match}}));
                         }
                         for my $old_sf ($from_field->subfields) {
                             $to_field->add_subfields( @$old_sf ) if grep(/$$old_sf[0]/,@{$fields{$f}{sf}});
@@ -1253,8 +1263,18 @@ CREATE OR REPLACE FUNCTION vandelay.strip_field(xml text, field text) RETURNS te
     for my $f ( keys %fields) {
         for my $to_field ($r->field( $f )) {
             if (exists($fields{$f}{match})) {
-                my @match_list = grep { $to_field->subfield($_) =~ $fields{$f}{match}{$_} } keys %{$fields{$f}{match}};
-                next unless (scalar(@match_list) == scalar(keys %{$fields{$f}{match}}));
+                my @match_list;
+                for my $match_key_sf_code ( keys %{$fields{$f}{match}} ) {
+                    # We loop here because there might be multiple SFs, such as multiple
+                    # $0s in an authority controlled datafield, where one has the EG-special
+                    # format, and others are links to external heading data.
+                    for my $sf_content ($to_field->subfield($match_key_sf_code)) {
+                        if ($sf_content =~ $fields{$f}{match}{$match_key_sf_code}) {
+                            push @match_list, $sf_content;
+                        }
+                    }
+                }
+                next unless (scalar(@match_list) >= scalar(keys %{$fields{$f}{match}}));
             }
 
             if ( @{$fields{$f}{sf}} ) {
@@ -1421,8 +1441,18 @@ CREATE OR REPLACE FUNCTION vandelay.replace_field
             # field spec contains a regex for this field.  Confirm field on 
             # target record matches the specified regex before replacing.
             if (exists($fields{$f}{match})) {
-                my @match_list = grep { $target_field->subfield($_) =~ $fields{$f}{match}{$_} } keys %{$fields{$f}{match}};
-                next unless (scalar(@match_list) == scalar(keys %{$fields{$f}{match}}));
+                my @match_list;
+                for my $match_key_sf_code ( keys %{$fields{$f}{match}} ) {
+                    # We loop here because there might be multiple SFs, such as multiple
+                    # $0s in an authority controlled datafield, where one has the EG-special
+                    # format, and others are links to external heading data.
+                    for my $sf_content ($target_field->subfield($match_key_sf_code)) {
+                        if ($sf_content =~ $fields{$f}{match}{$match_key_sf_code}) {
+                            push @match_list, $sf_content;
+                        }
+                    }
+                }
+                next unless (scalar(@match_list) >= scalar(keys %{$fields{$f}{match}}));
             }
 
             my @new_subfields;
@@ -1916,7 +1946,8 @@ BEGIN
         FROM vandelay.import_item
         WHERE record = import_id;
 
-    WHILE CARDINALITY(scope_orgs) > 0 LOOP
+    WHILE CARDINALITY(scope_orgs) IS NOT NULL LOOP
+        EXIT WHEN CARDINALITY(scope_orgs) = 0;
         FOR scope_org IN SELECT * FROM UNNEST(scope_orgs) LOOP
             -- For each match, get a count of all copies at descendants of our scope org.
             FOR rec IN SELECT * FROM vandelay.bib_match AS vbm
@@ -1938,12 +1969,15 @@ BEGIN
             END LOOP;
         END LOOP;
 
+        EXIT WHEN eg_id IS NOT NULL;
+
         -- If no matching bibs had holdings, gather our next set of orgs to check, and iterate.
         IF max_copy_count = 0 THEN 
             SELECT ARRAY_AGG(DISTINCT parent_ou) INTO scope_orgs
                 FROM actor.org_unit
                 WHERE id IN (SELECT * FROM UNNEST(scope_orgs))
                 AND parent_ou IS NOT NULL;
+            EXIT WHEN CARDINALITY(scope_orgs) IS NULL;
         END IF;
     END LOOP;
 
