@@ -19,7 +19,7 @@
 
 BEGIN;
 
-CREATE RULE protect_bib_rec_delete AS ON DELETE TO biblio.record_entry DO INSTEAD UPDATE biblio.record_entry SET deleted = TRUE WHERE OLD.id = biblio.record_entry.id RETURNING *;
+SELECT evergreen.setup_delete_protect_rule('biblio','record_entry');
 CREATE TRIGGER protect_bre_id_neg1 BEFORE UPDATE ON biblio.record_entry FOR EACH ROW WHEN (OLD.id = -1) EXECUTE PROCEDURE evergreen.raise_protected_row_exception();
 
 -- Kill any transaction that tries to mark a copy location as 
@@ -41,15 +41,14 @@ BEGIN
 END;
 $FUNK$ LANGUAGE plpgsql;
 
-CREATE RULE protect_copy_location_delete AS
-    ON DELETE TO asset.copy_location DO INSTEAD (
-        SELECT asset.check_delete_copy_location(OLD.id); -- exception on error
-        UPDATE asset.copy_location SET deleted = TRUE WHERE OLD.id = asset.copy_location.id RETURNING *;
-        UPDATE acq.lineitem_detail SET location = NULL WHERE location = OLD.id;
-        DELETE FROM asset.copy_location_order WHERE location = OLD.id;
-        DELETE FROM asset.copy_location_group_map WHERE location = OLD.id;
-        DELETE FROM config.circ_limit_set_copy_loc_map WHERE copy_loc = OLD.id;
-    );
+SELECT evergreen.setup_delete_protect_rule(
+    'asset', 'copy_location',
+    'SELECT asset.check_delete_copy_location(OLD.id);'
+      || ' UPDATE acq.lineitem_detail SET location = NULL WHERE location = OLD.id;'
+      || ' DELETE FROM asset.copy_location_order WHERE location = OLD.id;'
+      || ' DELETE FROM asset.copy_location_group_map WHERE location = OLD.id;'
+      || ' DELETE FROM config.circ_limit_set_copy_loc_map WHERE copy_loc = OLD.id;'
+);
 
 CREATE OR REPLACE FUNCTION asset.copy_location_validate_edit()
   RETURNS trigger
@@ -67,14 +66,7 @@ $function$;
 
 CREATE TRIGGER acpl_validate_edit BEFORE UPDATE ON asset.copy_location FOR EACH ROW EXECUTE PROCEDURE asset.copy_location_validate_edit();
 
-CREATE RULE protect_mono_part_delete AS
-    ON DELETE TO biblio.monograph_part DO INSTEAD (
-        UPDATE biblio.monograph_part
-            SET deleted = TRUE
-            WHERE OLD.id = biblio.monograph_part.id RETURNING *;
-        DELETE FROM asset.copy_part_map
-        WHERE part = OLD.id
-    );
+SELECT evergreen.setup_delete_protect_rule('biblio','monograph_part','DELETE FROM asset.copy_part_map WHERE part = OLD.id');
 
 ALTER TABLE actor.usr ADD CONSTRAINT actor_usr_mailing_address_fkey FOREIGN KEY (mailing_address) REFERENCES actor.usr_address (id) DEFERRABLE INITIALLY DEFERRED;
 ALTER TABLE actor.usr ADD CONSTRAINT actor_usr_billing_address_fkey FOREIGN KEY (billing_address) REFERENCES actor.usr_address (id) DEFERRABLE INITIALLY DEFERRED;
