@@ -109,6 +109,7 @@ INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VAL
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('pgt.name', '3', 'de-DE', 'Mitarbeiter');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('pgt.name', '6', 'de-DE', 'Erwerbungen');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('csg.label', 'acq', 'de-DE', 'Erwerbungen');
+INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('coust.label', 'circ.block_renews_for_holds', 'de-DE', 'Reservierungen: Verlängerung von Gegenständen, die für Reservierungen benötigt werden');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('coust.description', 'circ.max_fine.cap_at_price', 'de-DE', 'Dies hindert das System daran, mehr als den Einzelpreis in Verzugsgebühren zu berechnen');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '7', 'de-DE', 'Preis');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccpbt.label', 'misc', 'de-DE', 'Sonstiges');
@@ -609,6 +610,7 @@ INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VAL
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '611', 'de-DE', 'Blindenschrift');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '611', 'de-DE', 'Blindenschrift');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '908', 'de-DE', 'Blindenschrift');
+INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '1792', 'de-DE', 'Blindenschrift');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '532', 'de-DE', 'Sammlung');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '572', 'de-DE', 'Mikrofilm');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '572', 'de-DE', 'Mikrofilm');
@@ -645,3 +647,5 @@ INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VAL
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1308', 'de-DE', 'Samoanisch');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1323', 'de-DE', 'Mazedonisch');
 INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1331', 'de-DE', 'Slowenisch');
+INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '1787', 'de-DE', 'Zeichensprachen');
+INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1792', 'de-DE', 'Blindenschrift');
